# nps-fm-2020

<p align="center">
    <em>Python package to estimate the grades for the nps-fm-2020</em>
</p>

[![build](https://github.com/nps-fm-2020/workflows/Build/badge.svg)](https://github.com/nps-fm-2020/actions)
[![codecov](https://codecov.io/gh/nps-fm-2020/branch/master/graph/badge.svg)](https://codecov.io/gh/nps-fm-2020)
[![PyPI version](https://badge.fury.io/py/npsfm.svg)](https://badge.fury.io/py/npsfm)

---

**Documentation**: <a href="https://mullenkamp.github.io/nps-fm-2020/" target="_blank">https://mullenkamp.github.io/nps-fm-2020/</a>

**Source Code**: <a href="https://github.com/nps-fm-2020" target="_blank">https://github.com/nps-fm-2020</a>

---

## Purpose
nps-fm-2020 is a python package for calculating the attributes bands according to the [NZ NPS-FM 2020](https://environment.govt.nz/acts-and-regulations/national-policy-statements/national-policy-statement-freshwater-management/) using monitoring data and REC data as input. It is currently updated to the Jan 2024 version.

## License

This project is licensed under the terms of the Apache Software License 2.0.
